class IndexedList<T>(private val firstIndex: Int, private val lastIndex: Int, private val init: () -> T) {
    constructor(indices: IntRange, init: () -> T) : this(indices.first, indices.last, init)

    private val data = MutableList<T>(lastIndex - firstIndex + 1) { init() }
    fun add(element: T) = data.add(element)
    operator fun get(index: Int) = if (index in indices) data[index - firstIndex] else init()
    val indices: IntRange = firstIndex..lastIndex
    fun reduce(operation: (T, T) -> T) = data.reduce(operation)
}

operator fun List<Int>.compareTo(other: List<Int>): Int {
    for (i in indices) {
        if (i !in other.indices) return -1
        if (this[i] != other[i]) return this[i] - other[i]
    }
    return if (indices == other.indices) 0 else 1
}

fun main() {
    val n = readLine()!!.toInt()
    val k = readLine()!!.toInt()
    val dp = Array(k + 1) { IndexedList(-k * k..k * k) { IndexedList(-k..k) { mutableListOf<List<Int>>() } } }
    for (last in dp[0][0].indices) dp[0][0][last].add(mutableListOf())
    for (count in 1..k) {
        for (sum in dp[count].indices) {
            for (last in dp[count][sum].indices) {
                if (count > 1) for (partition in dp[count - 1][sum - last][last - 1]) dp[count][sum][last].add(partition + last)
                for (partition in dp[count - 1][sum - last][last]) dp[count][sum][last].add(partition + last)
                if (count > 1) for (partition in dp[count - 1][sum - last][last + 1]) dp[count][sum][last].add(partition + last)
            }
        }
    }
    val comparator = Comparator<List<Int>> { l1, l2 -> l1.compareTo(l2) }
    println(dp[k][n].reduce { a, b -> (a + b).toMutableList() }.sortedWith(comparator).joinToString("\n") {
        it.withIndex().joinToString("") { (if (it.index > 0 && it.value >= 0) "+" else "") + it.value.toString() }
    })
}

